==> sisu_7.1.7.orig.tar.xz: sisu-7.1.7/lib/sisu/zap.rb <==
# encoding: utf-8
=begin

* Name: SiSU

** Description: documents, structuring, processing, publishing, search
*** zap wipe clean previous output of the type specified

** Author: Ralph Amissah
  <ralph@amissah.com>
  <ralph.amissah@gmail.com>

** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Ralph Amissah,
  All Rights Reserved.

** License: GPL 3 or later:

  SiSU, a framework for document structuring, publishing and search

  Copyright (C) Ralph Amissah

  This program is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
  Software Foundation, either version 3 of the License, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along with
  this program. If not, see <http://www.gnu.org/licenses/>.

  If you have Internet connection, the latest version of the GPL should be
  available at these locations:
  <http://www.fsf.org/licensing/licenses/gpl.html>
  <http://www.gnu.org/licenses/gpl.html>

  <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>

** SiSU uses:
  * Standard SiSU markup syntax,
  * Standard SiSU meta-markup syntax, and the
  * Standard SiSU object citation numbering and system

** Hompages:
  <http://www.jus.uio.no/sisu>
  <http://www.sisudoc.org>

** Git
  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/zap.rb;hb=HEAD>

=end
module SiSU_Zap
  require_relative 'se'                                 # se.rb
    include SiSU_Env
  class Source
    def initialize(opt)
      @opt=opt
      @env=SiSU_Env::InfoEnv.new(opt.fns)
    end
    def read
      zap_path="#{@env.path.output}/#{@env.fnb}"
      z=SiSU_Env::CleanOutput.new(@opt)
      if SiSU_Env::InfoSettings.new.permission?('zap')
        unless @opt.act[:quiet][:set]==:on
          tell=SiSU_Screen::Ansi.new(
            @opt.act[:color_state][:set],
            "Clean files related to processing #{@opt.selections.str} ->",
            "#{@opt.fns} -> #{zap_path}"
          )
          tell.warn
        end
        z.zap.remove_output
      else
        unless @opt.act[:quiet][:set]==:on
          tell=SiSU_Screen::Ansi.new(
            @opt.act[:color_state][:set],
            'use of -Z (zap) has not enabled in sisurc.yml'
          )
          tell.warn
        end
      end
    end
  end
end
__END__

==> sisu_7.2.0.orig.tar.xz: sisu-7.2.0/lib/sisu/zap.rb <==
# encoding: utf-8
=begin

* Name: SiSU

** Description: documents, structuring, processing, publishing, search
*** zap wipe clean previous output of the type specified

** Author: Ralph Amissah
  [ralph@amissah.com]
  [ralph.amissah@gmail.com]

** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
  All Rights Reserved.

** License: GPL 3 or later:

  SiSU, a framework for document structuring, publishing and search

  Copyright (C) Ralph Amissah

  This program is free software: you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
  Software Foundation, either version 3 of the License, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along with
  this program. If not, see [http://www.gnu.org/licenses/].

  If you have Internet connection, the latest version of the GPL should be
  available at these locations:
  [http://www.fsf.org/licensing/licenses/gpl.html]
  [http://www.gnu.org/licenses/gpl.html]

** SiSU uses:
  * Standard SiSU markup syntax,
  * Standard SiSU meta-markup syntax, and the
  * Standard SiSU object citation numbering and system

** Hompages:
  [http://www.jus.uio.no/sisu]
  [http://www.sisudoc.org]

** Git
  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/zap.rb;hb=HEAD]

=end
module SiSU_Zap
  require_relative 'se'                                 # se.rb
    include SiSU_Env
  class Source
    def initialize(opt)
      @opt=opt
      @env=SiSU_Env::InfoEnv.new(opt.fns)
    end
    def read
      zap_path="#{@env.path.output}/#{@env.fnb}"
      z=SiSU_Env::CleanOutput.new(@opt)
      if SiSU_Env::InfoSettings.new.permission?('zap')
        unless @opt.act[:quiet][:set]==:on
          tell=SiSU_Screen::Ansi.new(
            @opt.act[:color_state][:set],
            "Clean files related to processing #{@opt.selections.str} ->",
            "#{@opt.fns} -> #{zap_path}"
          )
          tell.warn
        end
        z.zap.remove_output
      else
        unless @opt.act[:quiet][:set]==:on
          tell=SiSU_Screen::Ansi.new(
            @opt.act[:color_state][:set],
            'use of -Z (zap) has not enabled in sisurc.yml'
          )
          tell.warn
        end
      end
    end
  end
end
__END__
